@@ -1,37 +1,39 @@
-# @(#)$Id: PopupMenu.pm 335 2011-12-29 23:59:43Z pjf $
+# @(#)$Id: PopupMenu.pm 345 2012-03-03 17:50:47Z pjf $
 
 package HTML::FormWidgets::PopupMenu;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 335 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.10.%d', q$Rev: 345 $ =~ /\d+/gmx );
 use parent qw(HTML::FormWidgets);
 
-__PACKAGE__->mk_accessors( qw(labels values) );
+__PACKAGE__->mk_accessors( qw(classes labels values) );
 
 sub init {
    my ($self, $args) = @_;
 
-   $self->labels( undef );
-   $self->values( [] );
+   $self->classes( undef );
+   $self->labels ( undef );
+   $self->values ( [] );
    return;
 }
 
 sub render_field {
-   my ($self, $args)   = @_;
+   my ($self, $args) = @_;
 
    $self->class =~ m{ chzn-select }msx
       and $self->add_optional_js( q(chosen.js) );
 
    $args->{class} .= q( ).($self->class || q(ifield));
+   $self->classes  and $args->{classes } = $self->classes;
    $self->onchange and $args->{onchange} = $self->onchange;
 
    if ($self->labels) {
       my $labels = $args->{labels} = $self->labels;
 
       $args->{values} = [ sort {
-         ($labels->{ $a } || q()) cmp ($labels->{ $b } || q()) }
-                          @{ $self->values } ];
+         ($labels->{ $a } || q())
+            cmp ($labels->{ $b } || q()) } @{ $self->values } ];
    }
    else { $args->{values} = $self->values }
 
